package com.caimei.controller;


import com.alibaba.fastjson.JSONObject;
import com.caimei.model.ResponseJson;
import com.caimei.util.HttpRequest;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * 呵呵商城用户API
 *
 * @author : plf
 * @date : 2021/4/21
 */
@Api(tags = "呵呵商城用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/he")
public class HeHeApi {
    @Value("${caimei.userUrl}")
    private String userUrl;

    @ApiOperation("微信授权登录")
    @GetMapping("/authorization")
    public ResponseJson<String> authorization(String code) throws Exception {
        String url = userUrl + "/user/he/authorization?code=" + code;
        String parameters = HttpRequest.sendGet(url);
        return getResponseJson(parameters);
    }

    @ApiOperation("手机号验证码登录")
    @PostMapping("/mobile/login")
    public ResponseJson<String> mobileLogin(@RequestBody Map<String, Object> param) throws Exception {
        String url = userUrl + "/user/he/mobile/login";
        String parameters = HttpRequest.sendPost(url, param);
        return getResponseJson(parameters);
    }

    @ApiOperation("发送手机号验证码")
    @GetMapping("/send")
    public ResponseJson<String> sendVerificationCode(String mobile) throws Exception {
        String url = userUrl + "/user/he/send?mobile=" + mobile;
        String parameters = HttpRequest.sendGet(url);
        return getResponseJson(parameters);
    }

    private ResponseJson<String> getResponseJson(String parameters) {
        JSONObject object = JSONObject.parseObject(parameters);
        Integer code = object.getInteger("code");
        String msg = object.getString("msg");
        String data = object.getString("data");
        return ResponseJson.success(code, msg, data);
    }
}
