package com.caimei.model.vo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/26
 */
@Data
public class OrderProductVo implements Serializable {
    private Integer orderProductId;

    /**
     * 主订单ID
     */
    private Long orderId;

    /**
     * 订单Id
     */
    private Integer shopOrderId;

    /**
     * 供应商ID
     */
    private Long shopId;

    /**
     * 商品Id（采美商城和组织小程序都保存product表ID）
     */
    private Integer productId;

    /**
     * 购买数量
     */
    private Integer num;

    /**
     * 赠送数量
     */
    private Integer presentNum;

    /**
     * 出库类型 0 采美出库  1 供应商出库
     */
    private String outStoreType;

    /**
     * 商品编号
     */
    private String productNo;

    /**
     * 商品价格(协销 市场价 普通 购买价)
     */
    private BigDecimal price;

    /**
     * 市场价 = 商品表市场价
     */
    private BigDecimal normalPrice;

    /**
     * 购买时商品成本价
     */
    private BigDecimal costPrice;

    /**
     * 记录会员用户购买时价格  活动价优先
     */
    private BigDecimal price1;

    /**
     * 总价  = price X num
     */
    private BigDecimal totalAmount;

    /**
     * 总价  = discountPrice X num + totalAddedValueTax
     */
    private BigDecimal totalFee;

    /**
     * 应付金额 = totalFee - discountFee
     */
    private BigDecimal shouldPayFee;

    /**
     * 折扣比例
     */
    private BigDecimal discount;

    /**
     * 折后单价
     */
    private BigDecimal discountPrice;

    /**
     * 是否含税 0不含税 1含税 2未知
     */
    private String includedTax;

    /**
     * 发票类型 1增值税专用发票 2增值税普通发票 3不开发票
     */
    private String invoiceType;

    /**
     * 启用阶梯价格标识 0否 1是
     */
    private String ladderPriceFlag;

    /**
     * 后台设置该商品税率
     */
    private BigDecimal taxRate;

    /**
     * 供应商税率:增值专用发票默认13%，增值税普通发票6%取值范围[0-100]
     */
    private BigDecimal supplierTaxRate;

    /**
     * 单个税费=税率X折后单价
     */
    private BigDecimal addedValueTax;

    /**
     * 总税费=单个税费X购买数量
     */
    private BigDecimal totalAddedValueTax;

    /**
     * 总税费(应付税费)默认值和应收税费一样
     */
    private BigDecimal shouldPayTotalTax;

    /**
     * 单个付供应商税费
     */
    private BigDecimal singleShouldPayTotalTax;

    /**
     * 商品费
     */
    private BigDecimal shopProductAmount;

    /**
     * 订单商品状态
     */
    private String status;

    /**
     * 使用余额金额
     */
    private Double useBalanceAmount;

    /**
     * 未出库数量
     */
    private Integer notOutStore;

    /**
     * 下单时商品购买价格类型快照 0 机构价，1活动价 ，2阶梯价
     */
    private String isActProduct;

    /**
     * 是否是赠品 0 不是 1 是
     */
    private String isGiftProduct;

    /**
     * 活动信息 已享受满XX减XX 之类
     */
    private String productActInfo;

    /**
     * 订单商品再次购买标识 0否 1是
     */
    private String buyAgainFlag;

    /**
     * 订单商品供应商确认标志 0否 1是
     */
    private String confirmProductFlag;

    /**
     * 支付状态 0 未进账 1 待财务审核 2 已进账(适用协销的单笔线下进账和自助订单线下或异常进账)
     */
    private String payStatus;

    /**
     * 供应商名称
     */
    private String shopName;

    /**
     * 商品名称
     */
    private String name;

    /**
     * 商品单位
     */
    private String productUnit;

    private String productImage;

    /**
     * 活动类型 1000 热卖 1001 团购 1003 满减 1004满赠 1005 买赠
     */
    private String actType;

    /**
     * 商品类型(0正常商品,1协商赠品,2促销赠品)
     */
    private String productType;

    /**
     * 优惠 (price - discountPrice) * num
     */
    private BigDecimal preferential;

    /**
     * 协销订单:经理折扣(平摊到每个商品上,  按照每种商品的总价占订单总价的比例来均分);普通订单 无
     */
    private BigDecimal discountFee;

    private Integer cancelNum;

    /**
     * 分销者id(呵呵商城订单使用)
     */
    private Integer heUserId;

    /**
     * 已发货数量
     */
    private Integer shipmentsNum;

    /**
     * 已退货数量
     */
    private Integer returnedNum;

    /**
     * 已取消发货数量
     */
    private Integer actualCancelNum;

    /**
     * 商品前台展示单价是否含税，1不含税，2含税，3其他
     */
    private String includedTaxFlag;

    private static final long serialVersionUID = 1L;
}
