package com.caimei.model.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/26
 */
@Data
public class OrderVo implements Serializable {
    /**
     * orderID
     */
    private Integer orderId;

    /**
     * 订单编号(后台:p,网站:W,小程序:x,第三方:T)
     */
    private String orderNo;

    private Integer userId;

    /**
     * 下单人
     */
    private Integer buyUserId;

    /**
     * 子订单ID
     */
    private String shopOrderIds;

    /**
     * 0待确认,11待收待发,12待收部发,13待收全发,21部收待发,22部收部发,23部收全发,31已收待发,32已收部发,33已收全发,4交易完成,5订单完成,6已关闭,7交易全退
     */
    private String status;

    /**
     * （收款买家）收款状态：1待收款、2部分收款、3已收款
     */
    private String receiptStatus;

    /**
     * (付款供应商)付款状态：1待付款、2部分付款、3已付款
     */
    private String payStatus;

    /**
     * 发货状态：1待发货、2部分发货、3已发货
     */
    private String sendOutStatus;

    /**
     * 退货退款类型：1部分退、2全部退
     */
    private String refundType;

    /**
     * 已支付成功次数统计(适用线上多笔付款用来确认当前是哪一笔)
     */
    private Integer paySuccessCounter;

    /**
     * 是否已支付 未支付0 已支付1
     */
    private String payFlag;

    /**
     * 是否能走线上支付 0可以 1不可以 只能线下
     */
    private String onlinePayFlag;

    /**
     * 订单总额（小计金额减去经理折扣后，再加上运费）
     */
    private BigDecimal payTotalFee;

    /**
     * 真实支付金额（订单总额减去抵扣的账户余额）
     */
    private BigDecimal payableAmount;

    /**
     * 余额支付金额
     */
    private BigDecimal balancePayFee;

    /**
     * 经理折扣
     */
    private BigDecimal discountFee;

    /**
     * 促销满减优惠
     */
    private BigDecimal promotionFullReduction;

    /**
     * 订单备注
     */
    private String note;

    /**
     * 订单来源：1WWW、2CRM、3APP[历史数据]、4客服、5外单、6小程序[采美,星范等]
     */
    private String orderSource;

    /**
     * 订单提交时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private String orderTime;

    /**
     * 购买总数
     */
    private Integer productCount;

    /**
     * 赠送总数 不计算价格
     */
    private Integer presentCount;

    /**
     * 赠送总数
     */
    private Integer promotionalGiftsCount;


    /**
     * 是否开发票 没开发票 0 开个人发票 1 开企业发票2
     */
    private String invoiceFlag;

    /**
     * 条款ID
     */
    private Long clauseId;

    /**
     * 条款内容
     */
    private String clauseContent;

    /**
     * 条款名称
     */
    private String clauseName;

    /**
     * 免邮标志  运费：-1到付，0包邮，1需要运费,-2仪器到付其它包邮
     */
    private String freePostFlag;

    /**
     * -1到付，0包邮，大于0具体金额,-2仪器到付其它包邮（且运费已使用商品形式存储）
     */
    private BigDecimal freight;

    /**
     * 订单取消原因
     */
    private String closeReason;

    /**
     * 邮费订单标识(适用于补录邮费订单) 1是邮费订单  0不是邮费订单
     */
    private String postageOrderFlag;

    /**
     * 订单0成本标识：订单不是0成本，1订单0成本（订单中所有商品成本为0）
     */
    private Integer zeroCostFlag;

    /**
     * 付款总金额
     */
    private BigDecimal receiptAmount;

    /**
     * 待付总金额
     */
    private BigDecimal pendingPayments;

    /**
     * 退款总金额
     */
    private BigDecimal returnedPurchaseFee;

    /**
     * 订单标识:#订单号#
     */
    private String orderMark;

    /**
     * 总税费
     */
    private BigDecimal expensesOfTaxation;

    /**
     * 已退货数量
     */
    private Integer returnedNum;

    /**
     * 已取消数量
     */
    private Integer actualCancelNum;

    /**
     * 支付按钮是否消失,true消失
     */
    private boolean payButton = false;

    /**
     * 订单内是否包含确定能否开发票的商品
     */
    private boolean invoiceStatus = false;

    /**
     * 子订单列表
     */
    private List<ShopOrderVo> shopOrderList;

    private static final long serialVersionUID = 1L;
}
